@@ -71,8 +71,13 @@ module Bundler
       spec.installed_by_version = Gem::Version.create(installed_by_version)
     end
 
-    def spec_missing_extensions?(spec)
-      !spec.respond_to?(:missing_extensions?) || spec.missing_extensions?
+    def spec_missing_extensions?(spec, default = true)
+      return spec.missing_extensions? if spec.respond_to?(:missing_extensions?)
+
+      return false if spec.respond_to?(:default_gem?) && spec.default_gem?
+      return false if spec.extensions.empty?
+
+      default
     end
 
     def path(obj)
@@ -80,6 +85,7 @@ module Bundler
     end
 
     def platforms
+      return [Gem::Platform::RUBY] if Bundler.settings[:force_ruby_platform]
       Gem.platforms
     end
 
@@ -194,6 +200,10 @@ module Bundler
       end
     end
 
+    def load_plugins
+      Gem.load_plugins if Gem.respond_to?(:load_plugins)
+    end
+
     def ui=(obj)
       Gem::DefaultUserInteraction.ui = obj
     end
@@ -203,6 +213,7 @@ module Bundler
     end
 
     def fetch_specs(all, pre, &blk)
+      require "rubygems/spec_fetcher"
       specs = Gem::SpecFetcher.new.list(all, pre)
       specs.each { yield } if block_given?
       specs
@@ -243,6 +254,10 @@ module Bundler
       end
     end
 
+    def install_with_build_args(args)
+      with_build_args(args) { yield }
+    end
+
     def gem_from_path(path, policy = nil)
       require "rubygems/format"
       Gem::Format.from_file_by_path(path, policy)
@@ -710,6 +725,10 @@ module Bundler
       def repository_subdirectories
         Gem::REPOSITORY_SUBDIRECTORIES
       end
+
+      def install_with_build_args(args)
+        yield
+      end
     end
 
     # RubyGems 2.1.0
@@ -750,6 +769,14 @@ module Bundler
           end.map(&:to_spec)
         end
       end
+
+      def use_gemdeps(gemfile)
+        ENV["BUNDLE_GEMFILE"] ||= File.expand_path(gemfile)
+        runtime = Bundler.setup
+        Bundler.ui = nil
+        activated_spec_names = runtime.requested_specs.map(&:to_spec).sort_by(&:name)
+        [Gemdeps.new(runtime), activated_spec_names]
+      end
     end
   end
 
